/*
 * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_cy extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "AED", "AED" },
            { "AFA", "AFA" },
            { "AFN", "AFN" },
            { "ALL", "ALL" },
            { "AMD", "AMD" },
            { "ANG", "ANG" },
            { "AOA", "AOA" },
            { "AOK", "AOK" },
            { "AON", "AON" },
            { "AOR", "AOR" },
            { "ARA", "ARA" },
            { "ARL", "ARL" },
            { "ARM", "ARM" },
            { "ARP", "ARP" },
            { "ARS", "ARS" },
            { "ATS", "ATS" },
            { "AWG", "AWG" },
            { "AZM", "AZM" },
            { "AZN", "AZN" },
            { "BAM", "BAM" },
            { "BBD", "BBD" },
            { "BDT", "BDT" },
            { "BEC", "BEC" },
            { "BEF", "BEF" },
            { "BEL", "BEL" },
            { "BGM", "BGM" },
            { "BGN", "BGN" },
            { "BGO", "BGO" },
            { "BHD", "BHD" },
            { "BIF", "BIF" },
            { "BMD", "BMD" },
            { "BND", "BND" },
            { "BOB", "BOB" },
            { "BOL", "BOL" },
            { "BOP", "BOP" },
            { "BOV", "BOV" },
            { "BRB", "BRB" },
            { "BRC", "BRC" },
            { "BRE", "BRE" },
            { "BRN", "BRN" },
            { "BRR", "BRR" },
            { "BRZ", "BRZ" },
            { "BSD", "BSD" },
            { "BTN", "BTN" },
            { "BUK", "BUK" },
            { "BWP", "BWP" },
            { "BYN", "BYN" },
            { "BYR", "BYR" },
            { "BZD", "BZD" },
            { "CDF", "CDF" },
            { "CHE", "CHE" },
            { "CHF", "CHF" },
            { "CHW", "CHW" },
            { "CLE", "CLE" },
            { "CLF", "CLF" },
            { "CLP", "CLP" },
            { "CNH", "CNH" },
            { "COP", "COP" },
            { "COU", "COU" },
            { "CRC", "CRC" },
            { "CSD", "CSD" },
            { "CUC", "CUC" },
            { "CUP", "CUP" },
            { "CVE", "CVE" },
            { "CYP", "CYP" },
            { "CZK", "CZK" },
            { "DDM", "DDM" },
            { "DEM", "DEM" },
            { "DJF", "DJF" },
            { "DKK", "DKK" },
            { "DOP", "DOP" },
            { "DZD", "DZD" },
            { "ECS", "ECS" },
            { "EGP", "EGP" },
            { "ERN", "ERN" },
            { "ESP", "ESP" },
            { "ETB", "ETB" },
            { "FIM", "FIM" },
            { "FJD", "FJD" },
            { "FKP", "FKP" },
            { "FRF", "FRF" },
            { "GEK", "GEK" },
            { "GEL", "GEL" },
            { "GHC", "GHC" },
            { "GHS", "GHS" },
            { "GIP", "GIP" },
            { "GMD", "GMD" },
            { "GNF", "GNF" },
            { "GNS", "GNS" },
            { "GQE", "GQE" },
            { "GRD", "GRD" },
            { "GTQ", "GTQ" },
            { "GWE", "GWE" },
            { "GWP", "GWP" },
            { "GYD", "GYD" },
            { "HNL", "HNL" },
            { "HRD", "HRD" },
            { "HRK", "HRK" },
            { "HTG", "HTG" },
            { "HUF", "HUF" },
            { "IDR", "IDR" },
            { "IEP", "IEP" },
            { "ILP", "ILP" },
            { "IQD", "IQD" },
            { "IRR", "IRR" },
            { "ISK", "ISK" },
            { "ITL", "ITL" },
            { "JMD", "JMD" },
            { "JOD", "JOD" },
            { "KES", "KES" },
            { "KGS", "KGS" },
            { "KHR", "KHR" },
            { "KMF", "KMF" },
            { "KPW", "KPW" },
            { "KRH", "KRH" },
            { "KRO", "KRO" },
            { "KRW", "KRW" },
            { "KWD", "KWD" },
            { "KYD", "KYD" },
            { "KZT", "KZT" },
            { "LAK", "LAK" },
            { "LBP", "LBP" },
            { "LKR", "LKR" },
            { "LRD", "LRD" },
            { "LSL", "LSL" },
            { "LTL", "LTL" },
            { "LTT", "LTT" },
            { "LUC", "LUC" },
            { "LUF", "LUF" },
            { "LUL", "LUL" },
            { "LVL", "LVL" },
            { "LVR", "LVR" },
            { "LYD", "LYD" },
            { "MAD", "MAD" },
            { "MAF", "MAF" },
            { "MCF", "MCF" },
            { "MDL", "MDL" },
            { "MGA", "MGA" },
            { "MGF", "MGF" },
            { "MKD", "MKD" },
            { "MKN", "MKN" },
            { "MLF", "MLF" },
            { "MMK", "MMK" },
            { "MNT", "MNT" },
            { "MOP", "MOP" },
            { "MRO", "MRO" },
            { "MRU", "MRU" },
            { "MTL", "MTL" },
            { "MTP", "MTP" },
            { "MUR", "MUR" },
            { "MVR", "MVR" },
            { "MWK", "MWK" },
            { "MXP", "MXP" },
            { "MXV", "MXV" },
            { "MYR", "MYR" },
            { "MZE", "MZE" },
            { "MZM", "MZM" },
            { "MZN", "MZN" },
            { "NAD", "NAD" },
            { "NGN", "NGN" },
            { "NIC", "NIC" },
            { "NIO", "NIO" },
            { "NLG", "NLG" },
            { "NOK", "NOK" },
            { "NPR", "NPR" },
            { "OMR", "OMR" },
            { "PAB", "PAB" },
            { "PEI", "PEI" },
            { "PEN", "PEN" },
            { "PES", "PES" },
            { "PGK", "PGK" },
            { "PHP", "PHP" },
            { "PKR", "PKR" },
            { "PLN", "PLN" },
            { "PTE", "PTE" },
            { "PYG", "PYG" },
            { "QAR", "QAR" },
            { "RHD", "RHD" },
            { "RON", "RON" },
            { "RSD", "RSD" },
            { "RUB", "RUB" },
            { "RWF", "RWF" },
            { "SAR", "SAR" },
            { "SBD", "SBD" },
            { "SCR", "SCR" },
            { "SDD", "SDD" },
            { "SDG", "SDG" },
            { "SDP", "SDP" },
            { "SEK", "SEK" },
            { "SGD", "SGD" },
            { "SHP", "SHP" },
            { "SIT", "SIT" },
            { "SLL", "SLL" },
            { "SOS", "SOS" },
            { "SRD", "SRD" },
            { "SRG", "SRG" },
            { "SSP", "SSP" },
            { "STD", "STD" },
            { "STN", "STN" },
            { "SVC", "SVC" },
            { "SYP", "SYP" },
            { "SZL", "SZL" },
            { "THB", "\u0e3f" },
            { "TJR", "TJR" },
            { "TJS", "TJS" },
            { "TMM", "TMM" },
            { "TMT", "TMT" },
            { "TND", "TND" },
            { "TOP", "TOP" },
            { "TPE", "TPE" },
            { "TRL", "TRL" },
            { "TRY", "TRY" },
            { "TTD", "TTD" },
            { "TZS", "TZS" },
            { "UAH", "UAH" },
            { "UGS", "UGS" },
            { "UGX", "UGX" },
            { "USN", "USN" },
            { "USS", "USS" },
            { "UYI", "UYI" },
            { "UYP", "UYP" },
            { "UYU", "UYU" },
            { "UZS", "UZS" },
            { "VEB", "VEB" },
            { "VEF", "VEF" },
            { "VES", "VES" },
            { "VNN", "VNN" },
            { "VUV", "VUV" },
            { "WST", "WST" },
            { "XEU", "XEU" },
            { "XXX", "XXX" },
            { "YDD", "YDD" },
            { "YER", "YER" },
            { "YUD", "YUD" },
            { "YUM", "YUM" },
            { "YUN", "YUN" },
            { "YUR", "YUR" },
            { "ZAL", "ZAL" },
            { "ZAR", "ZAR" },
            { "ZMK", "ZMK" },
            { "ZMW", "ZMW" },
            { "ZRN", "ZRN" },
            { "ZRZ", "ZRZ" },
            { "ZWD", "ZWD" },
            { "ZWL", "ZWL" },
            { "ZWR", "ZWR" },
            { "aed", "Dirham Yr Emiradau Arabaidd Unedig" },
            { "afa", "Afghani Afghanistan (1927\u20132002)" },
            { "afn", "Afghani Afghanistan" },
            { "all", "Lek Albania" },
            { "amd", "Dram Armenia" },
            { "ang", "Guilder Antilles yr Iseldiroedd" },
            { "aoa", "Kwanza Angola" },
            { "aok", "Kwanza Angola (1977\u20131991)" },
            { "aon", "Kwanza Newydd Angola (1990\u20132000)" },
            { "aor", "Kwanza Ailgymhwysedig Angola (1995\u20131999)" },
            { "ara", "Austral yr Ariannin" },
            { "arl", "Peso Ley yr Ariannin (1970\u20131983)" },
            { "arm", "Peso yr Ariannin (1881\u20131970)" },
            { "arp", "Peso yr Ariannin (1983\u20131985)" },
            { "ars", "Peso yr Ariannin" },
            { "ats", "Swllt Awstria" },
            { "aud", "Doler Awstralia" },
            { "awg", "Fflorin Aruba" },
            { "azm", "Manat Azerbaijan (1993\u20132006)" },
            { "azn", "Manat Azerbaijan" },
            { "bam", "Marc Trosadwy Bosnia a Hercegovina" },
            { "bbd", "Doler Barbados" },
            { "bdt", "Taka Bangladesh" },
            { "bec", "Ffranc Gwlad Belg (arnewidiol)" },
            { "bef", "Ffranc Gwlad Belg" },
            { "bel", "Ffranc Gwlad Belg (ariannol)" },
            { "bgm", "Lev Sosialaidd Bwlgaria" },
            { "bgn", "Lev Bwlgaria" },
            { "bgo", "Lev Bwlgaria (1879\u20131952)" },
            { "bhd", "Dinar Bahrain" },
            { "bif", "Ffranc Burundi" },
            { "bmd", "Doler Bermuda" },
            { "bnd", "Doler Brunei" },
            { "bob", "Boliviano Bolifia" },
            { "bol", "Boliviano Bolifia (1863\u20131963)" },
            { "bop", "Peso Bolifia" },
            { "bov", "Mvdol Bolifia" },
            { "brb", "Cruzeiro Newydd Brasil (1967\u20131986)" },
            { "brc", "Cruzado Brasil (1986\u20131989)" },
            { "bre", "Cruzeiro Brasil (1990\u20131993)" },
            { "brl", "Real Brasil" },
            { "brn", "Cruzado Newydd Brasil (1989\u20131990)" },
            { "brr", "Cruzeiro Brasil (1993\u20131994)" },
            { "brz", "Cruzeiro Brasil (1942\u20131967)" },
            { "bsd", "Doler y Bahamas" },
            { "btn", "Ngultrum Bhutan" },
            { "buk", "Kyat Byrma" },
            { "bwp", "Pula Botswana" },
            { "byn", "Rwbl Belarws" },
            { "byr", "Rwbl Belarws (2000\u20132016)" },
            { "bzd", "Doler Belize" },
            { "cad", "Doler Canada" },
            { "cdf", "Ffranc Congo" },
            { "che", "Ewro WIR" },
            { "chf", "Ffranc y Swistir" },
            { "chw", "Ffranc WIR" },
            { "cle", "Escudo Chile" },
            { "clf", "Uned Cyfrifo Chile (UF)" },
            { "clp", "Peso Chile" },
            { "cnh", "Yuan Tsieina (ar y m\u00f4r)" },
            { "cnx", "Doler Banc Pobl Tsieina" },
            { "cny", "Yuan Tsieina" },
            { "cop", "Peso Colombia" },
            { "cou", "Uned Gwir Werth Colombia" },
            { "crc", "Col\u00f3n Costa Rica" },
            { "cuc", "Peso Trosadwy Ciwba" },
            { "cup", "Peso Ciwba" },
            { "cve", "Esgwdo Cabo Verde" },
            { "cyp", "Punt Cyprus" },
            { "czk", "Koruna\u2019r Weriniaeth Tsiec" },
            { "ddm", "Marc Dwyrain yr Almaen" },
            { "dem", "Marc yr Almaen" },
            { "djf", "Ffranc Djibouti" },
            { "dkk", "Krone Denmarc" },
            { "dop", "Peso Gweriniaeth Dominica" },
            { "dzd", "Dinar Algeria" },
            { "ecs", "Sucre Ecuador" },
            { "ecv", "Uned Gwerth Gyson Ecuador" },
            { "eek", "Kroon Estonia" },
            { "egp", "Punt Yr Aifft" },
            { "ern", "Nakfa Eritrea" },
            { "etb", "Birr Ethiopia" },
            { "eur", "Ewro" },
            { "fim", "Markka\u2019r Ffindir" },
            { "fjd", "Doler Ffiji" },
            { "fkp", "Punt Ynysoedd Falkland/Malvinas" },
            { "frf", "Ffranc Ffrainc" },
            { "gbp", "Punt Prydain" },
            { "gek", "Kupon Larit Georgia" },
            { "gel", "Lari Georgia" },
            { "ghc", "Cedi Ghana (1979\u20132007)" },
            { "ghs", "Cedi Ghana" },
            { "gip", "Punt Gibraltar" },
            { "gmd", "Dalasi Gambia" },
            { "gnf", "Ffranc Guin\u00e9e" },
            { "gns", "Syli Guin\u00e9e" },
            { "gqe", "Ekwele Guinea Gyhydeddol" },
            { "gtq", "Quetzal Guatemala" },
            { "gwp", "Peso Guin\u00e9-Bissau" },
            { "gyd", "Doler Guyana" },
            { "hkd", "Doler Hong Kong" },
            { "hnl", "Lempira Honduras" },
            { "hrk", "Kuna Croatia" },
            { "htg", "Gourde Haiti" },
            { "huf", "Fforint Hwngari" },
            { "idr", "Rupiah Indonesia" },
            { "iep", "Punt Iwerddon" },
            { "ilp", "Punt Israel" },
            { "ilr", "Shegel Israel (1980\u20131985)" },
            { "ils", "Shegel Newydd Israel" },
            { "inr", "Rwp\u00ee India" },
            { "iqd", "Dinar Irac" },
            { "irr", "Rial Iran" },
            { "isj", "Kr\u00f3na Gwlad yr I\u00e2 (1918 \u2013 1981)" },
            { "isk", "Kr\u00f3na Gwlad yr I\u00e2" },
            { "jmd", "Doler Jamaica" },
            { "jod", "Dinar Gwlad yr Iorddonen" },
            { "jpy", "Yen Japan" },
            { "kes", "Swllt Kenya" },
            { "kgs", "Som Kyrgyzstan" },
            { "khr", "Riel Cambodia" },
            { "kmf", "Ffranc Comoros" },
            { "kpw", "Won Gogledd Corea" },
            { "krh", "Hwan De Corea (1953\u20131962)" },
            { "kro", "Won De Corea (1945\u20131953)" },
            { "krw", "Won De Corea" },
            { "kwd", "Dinar Kuwait" },
            { "kyd", "Doler Ynysoedd Cayman" },
            { "kzt", "Tenge Kazakstan" },
            { "lak", "Kip Laos" },
            { "lbp", "Punt Libanus" },
            { "lkr", "Rwp\u00ee Sri Lanka" },
            { "lrd", "Doler Liberia" },
            { "lsl", "Loti Lesotho" },
            { "ltl", "Litas Lithwania" },
            { "ltt", "Talonas Lithwania" },
            { "luf", "Ffranc Lwcsembwrg" },
            { "lvl", "Lats Latfia" },
            { "lvr", "Rwbl Latfia" },
            { "lyd", "Dinar Libya" },
            { "mad", "Dirham Moroco" },
            { "maf", "Ffranc Moroco" },
            { "mcf", "Ffranc Monaco" },
            { "mdl", "Leu Moldofa" },
            { "mga", "Ariary Madagascar" },
            { "mgf", "Ffranc Madagascar" },
            { "mkd", "Denar Macedonia" },
            { "mlf", "Ffranc Mali" },
            { "mmk", "Kyat Myanmar" },
            { "mnt", "Tugrik Mongolia" },
            { "mop", "Pataca Macau" },
            { "mro", "Ouguiya Mauritania (1973\u20132017)" },
            { "mru", "Ouguiya Mauritania" },
            { "mur", "Rwp\u00ee Mauritius" },
            { "mvp", "Rwp\u00ee\u2019r Maldives (1947\u20131981)" },
            { "mvr", "Rufiyaa\u2019r Maldives" },
            { "mwk", "Kwacha Malawi" },
            { "mxn", "Peso Mecsico" },
            { "mxp", "Peso Arian M\u00e9xico (1861\u20131992)" },
            { "mxv", "Uned Fuddsoddi M\u00e9xico" },
            { "myr", "Ringgit Malaysia" },
            { "mze", "Escudo Mozambique" },
            { "mzm", "Metical Mozambique (1980\u20132006)" },
            { "mzn", "Metical Mozambique" },
            { "nad", "Doler Namibia" },
            { "ngn", "Naira Nigeria" },
            { "nic", "C\u00f3rdoba Nicaragua (1988\u20131991)" },
            { "nio", "Cordoba Nicaragwa" },
            { "nlg", "Guilder yr Iseldiroedd" },
            { "nok", "Krone Norwy" },
            { "npr", "Rwp\u00ee Nepal" },
            { "nzd", "Doler Seland Newydd" },
            { "omr", "Rial Oman" },
            { "pab", "Balboa Panama" },
            { "pei", "Inti Periw" },
            { "pen", "Sol Periw" },
            { "pes", "Sol Periw (1863\u20131965)" },
            { "pgk", "Kina Papua Guinea Newydd" },
            { "php", "Peso Philipinas" },
            { "pkr", "Rwp\u00ee Pacistan" },
            { "pln", "Zloty Gwlad Pwyl" },
            { "pyg", "Guarani Paraguay" },
            { "qar", "Rial Qatar" },
            { "rhd", "Doler Rhodesia" },
            { "ron", "Leu Rwmania" },
            { "rsd", "Dinar Serbia" },
            { "rub", "Rwbl Rwsia" },
            { "rwf", "Ffranc Rwanda" },
            { "sar", "Riyal Saudi Arabia" },
            { "sbd", "Doler Ynysoedd Solomon" },
            { "scr", "Rwp\u00ee Seychelles" },
            { "sdd", "Dinar Sudan (1992\u20132007)" },
            { "sdg", "Punt Sudan" },
            { "sdp", "Punt Sudan (1957\u20131998)" },
            { "sek", "Krona Sweden" },
            { "sgd", "Doler Singapore" },
            { "shp", "Punt St Helena" },
            { "sll", "Leone Sierra Leone" },
            { "sos", "Swllt Somalia" },
            { "srd", "Doler Surinam" },
            { "srg", "Guilder Surinam" },
            { "ssp", "Punt De Sudan" },
            { "std", "Dobra S\u00e3o Tom\u00e9 a Pr\u00edncipe (1977\u20132017)" },
            { "stn", "Dobra S\u00e3o Tom\u00e9 a Pr\u00edncipe" },
            { "svc", "Col\u00f3n El Salvador" },
            { "syp", "Punt Syria" },
            { "szl", "Lilangeni Gwlad Swazi" },
            { "thb", "Baht Gwlad Thai" },
            { "tjr", "Rwbl Tajikistan" },
            { "tjs", "Somoni Tajikistan" },
            { "tmm", "Manat Turkmenistan (1993\u20132009)" },
            { "tmt", "Manat Turkmenistan" },
            { "tnd", "Dinar Tunisia" },
            { "top", "Pa\u02bbanga Tonga" },
            { "tpe", "Escudo Timor" },
            { "trl", "Lira Twrci (1922\u20132005)" },
            { "try", "Lira Twrci" },
            { "ttd", "Doler Trinidad a Tobago" },
            { "twd", "Doler Newydd Taiwan" },
            { "tzs", "Swllt Tanzania" },
            { "uah", "Hryvnia Wcr\u00e1in" },
            { "ugs", "Swllt Uganda (1966\u20131987)" },
            { "ugx", "Swllt Uganda" },
            { "usd", "Doler UDA" },
            { "usn", "Doler UDA (y diwrnod nesaf)" },
            { "uss", "Doler UDA (yr un diwrnod)" },
            { "uyp", "Peso Uruguay (1975\u20131993)" },
            { "uyu", "Peso Uruguay" },
            { "uzs", "Som Uzbekistan" },
            { "veb", "Bol\u00edvar Venezuela (1871\u20132008)" },
            { "vef", "Bol\u00edvar Venezuela (2008\u20132018)" },
            { "ves", "Bol\u00edvar Venezuela" },
            { "vnd", "Dong Fietnam" },
            { "vnn", "Dong Fietnam (1978\u20131985)" },
            { "vuv", "Vatu Vanuatu" },
            { "wst", "Tala Samoa" },
            { "xaf", "Ffranc CFA Canol Affrica" },
            { "xag", "Arian" },
            { "xau", "Aur" },
            { "xba", "Uned Cyfansawdd Ewropeaidd" },
            { "xbb", "Uned Ariannol Ewropeaidd" },
            { "xcd", "Doler Dwyrain y Carib\u00ee" },
            { "xeu", "Uned Arian Cyfred Ewropeaidd" },
            { "xof", "Ffranc CFA Gorllewin Affrica" },
            { "xpd", "Paladiwm" },
            { "xpf", "Ffranc CFP" },
            { "xpt", "Platinwm" },
            { "xsu", "Sucre" },
            { "xxx", "Arian Cyfred Anhysbys" },
            { "ydd", "Dinar Yemen" },
            { "yer", "Rial Yemen" },
            { "zal", "Rand (ariannol) De Affrica" },
            { "zar", "Rand De Affrica" },
            { "zmk", "Kwacha Zambia (1968\u20132012)" },
            { "zmw", "Kwacha Zambia" },
            { "zrn", "Zaire Newydd Zaire (1993\u20131998)" },
            { "zrz", "Zaire Zaire (1971\u20131993)" },
            { "zwd", "Doler Zimbabwe (1980\u20132008)" },
            { "zwl", "Doler Zimbabwe (2009)" },
            { "zwr", "Doler Zimbabwe (2008)" },
        };
        return data;
    }
}
